featurizationMethodParameters property
The method parameters (key-value pairs), which are a map of override parameters. Specify these parameters to override the default values. Related Time Series attributes do not accept aggregation parameters.
The following list shows the parameters and their valid values for the "filling" featurization method for a Target Time Series dataset. Bold signifies the default value.
-
aggregation: sum,avg,first,min,max -
frontfill: none -
middlefill: zero,nan(not a number),value,median,mean,min,max -
backfill: zero,nan,value,median,mean,min,max
-
middlefill:zero,value,median,mean,min,max -
backfill:zero,value,median,mean,min,max -
futurefill:zero,value,median,mean,min,max
value and define the value in a corresponding
_value parameter. For example, to set backfilling to a value of
2, include the following: "backfill": "value" and
"backfill_value":"2".
Implementation
final Map<String, String>? featurizationMethodParameters;